import sympy as sp

def decompose_mono(matexpr) -> dict:
    '''
    把矩阵单项式拆分成系数和矩阵
    '''
    dic = {'coe':1, 'mat':0}
    if isinstance(matexpr, sp.MatrixBase):
        dic['mat'] = matexpr
        return dic
    else:
        for x in matexpr.args:
            if isinstance(x, sp.MatrixBase):
                dic['mat'] = x
            else:
                dic['coe'] = x
        return dic


from typing import List
from sympy.matrices.dense import MutableDenseMatrix

class matSolver:

    def __init__(self, mat: MutableDenseMatrix) -> None:
        self.mat: MutableDenseMatrix = mat
        self.course: List = []
        self.dim: int = mat.shape[0]

    def get_course(self) -> list:
        return self.course

class CoreSolver:

    def __init__(self, evaluate=True) -> None:
        self.evaluate = False
        if evaluate:
            self.execute()
            self.evaluate = True

    def execute(self) -> None:
        if not self.evaluate:
            self.toExecute()
            self.evaluate = True

    def toExecute(self) -> None:
        pass

    def dict(self) -> dict:
        if not self.evaluate:
            self.execute()
        return self.toDict()
    
    def toDict(self) -> dict:
        pass

    